import express from "express"; //ECMA6 ES2015 syntax, supported by latest Chrome & NodeJS
import cors from "cors";
import Database from "better-sqlite3";

const PORT = 8000;
const app = express();

app.use(cors()); // allow server to accept requests from other domains
app.use(express.json()); // requests and responses should be JSON / dictionaries

// GET, POST, PUT ..
app.get('/', async (req, res) => {
   res.send('It works!');
});

//! POST
app.post('/get_scores', async (req, res) => {
   console.log(req.body); // JSON / Dict
   let response = {
     is_success: false,
     scores: []
   };

   try {
     let db = new Database('space_invaders.sqlite');
     let query = db.prepare(
       'SELECT player_name, score FROM scores WHERE score > @threshold ORDER BY score DESC LIMIT 10'
     );
     response.scores = query.all(
       {
         threshold: 0
       }
     )
     response.is_success = true;
   }
   catch (e) {
      console.error(e);
   }

   res.send(response);
});

app.post('/insert_score', async (req, res) => {
  console.log(req.body); // JSON / Dict
  let response = {
    is_success: false,
    score_id: 0
  };

  try {
    let db = new Database('space_invaders.sqlite');
    let query = db.prepare(
      'INSERT INTO scores (player_name, score) VALUES (@name, @score)'
    ); // for SQL look W3Schools tutorials
    let result = query.run({
      name: req.body.name,
      score: req.body.score,
    })
    response.is_success = true;
    response.score_id = result.lastInsertRowid; // better-sqlite3 look up documentation
  }
  catch (e) {
    console.error(e);
  }

  res.send(response);
});

app.post('/delete_score', async (req, res) => {
  console.log(req.body); // JSON / Dict
  let response = {
    is_success: false
  };

  try {
    let db = new Database('space_invaders.sqlite');
    let query = db.prepare(
      'DELETE FROM scores WHERE player_name = @name'
    ); // for SQL look W3Schools tutorials
    let result = query.run({
      name: req.body.name
    })
  }
  catch (e) {
    console.error(e);
  }

  res.send(response);
});

app.listen(PORT, () => {
    console.log(`Server running on http://localhost:${PORT}`);
})
